@@ -1,4 +1,6 @@
+from collections import defaultdict
 from discord.ext import commands
+from typing import Callable
 import traceback
 import aiohttp
 import asyncio
@@ -12,9 +14,11 @@ STAT_ENDPOINT = "https://api.statcord.com/v3/stats"
 class StatcordClient:
     """The base Statcord client class."""
 
-    def __init__(self, bot: commands.Bot, statcord_key: str, custom_1: object = None, custom_2: object = None):
+    def __init__(self, bot: commands.Bot, statcord_key: str, custom_1: Callable = None, custom_2: Callable = None) -> None:
         self.bot = bot
+
         self.statcord_key = statcord_key
+
         self.custom_1 = custom_1
         self.custom_2 = custom_2
 
@@ -41,7 +45,7 @@ class StatcordClient:
         # create counters
         net_io_counter = psutil.net_io_counters()
         self._prev_net_usage = net_io_counter.bytes_sent + net_io_counter.bytes_recv
-        self._popular_commands = {}
+        self._popular_commands = defaultdict(int)
         self._command_count = 0
         self._active_users = set()
 
@@ -79,20 +83,15 @@ class StatcordClient:
 
             return count
 
-    async def _command_ran(self, ctx) -> None:
+    async def _command_ran(self, ctx: commands.Context) -> None:
         """Updates command-related statistics."""
 
         if ctx.command_failed:
             return
 
         self._command_count += 1
-
         self._active_users.add(ctx.author.id)
-
-        try:
-            self._popular_commands[ctx.command.name] += 1
-        except KeyError:
-            self._popular_commands[ctx.command.name] = 1
+        self._popular_commands[ctx.command.name] += 1
 
     async def _post_loop(self) -> None:
         """The stat posting loop which posts stats to the Statcord API."""
@@ -107,13 +106,13 @@ class StatcordClient:
 
             await asyncio.sleep(60)
 
-    async def _call_custom_graph(self, callable) -> object:
+    async def _call_custom_graph(self, callable: Callable) -> object:
         if self.custom_2 is None:
             return 0
 
         if asyncio.iscoroutinefunction(self.custom_2):
             return await callable()
-                
+
         return callable()
 
     async def post_stats(self) -> None:
@@ -154,7 +153,7 @@ class StatcordClient:
         }
 
         # reset counters
-        self._popular_commands = {}
+        self._popular_commands = defaultdict(int)
         self._command_count = 0
         self._active_users = set()
 
